import {
    act,
    renderHook,
} from '@testing-library/react-hooks';

import useExpandToggle from './useExpandToggle';


describe('useExpandToggle', () => {

    it('should use default value', () => {
        const { result } = renderHook(() => useExpandToggle());
        expect(result.current.action).toBe('');
        expect(result.current.value).toBe(false);
    });

    it('should use initial value', () => {
        const { result } = renderHook(() => useExpandToggle({
            initialExpanded: true,
        }));

        expect(result.current.action).toBe('');
        expect(result.current.value).toBe(true);
    });

    test.each([
        false,
        true,
    ])('toggle %s', (initialExpanded) => {
        const { result } = renderHook(() => useExpandToggle({ initialExpanded }));
        act(() => { result.current.toggle(); });

        expect(result.current.action).toBe('');
        expect(result.current.value).toBe(!initialExpanded);
    });

    test('toggle from action', () => {
        const { result } = renderHook(() => useExpandToggle({
            initialAction: 'action',
            initialExpanded: true,
        }));

        act(() => { result.current.toggle(); });

        expect(result.current.action).toBe('');
        expect(result.current.value).toBe(false);
    });

    test.each([
        false,
        true,
    ])('toggleWith %s', (initialExpanded) => {
        const { result } = renderHook(() => useExpandToggle({
            initialAction: initialExpanded ? 'action' : '',
            initialExpanded,
        }));

        act(() => { result.current.toggleWith('action'); });

        expect(result.current.action).toBe(
            result.current.value
                ? 'action'
                : '',
        );
        expect(result.current.value).toBe(!initialExpanded);
    });

    test.each([
        false,
        true,
    ])('toggleWith new action %s', (initialExpanded) => {
        const { result } = renderHook(() => useExpandToggle({
            initialAction: 'action',
            initialExpanded,
        }));

        act(() => { result.current.toggleWith('new-action'); });

        expect(result.current.action).toBe('new-action');
        expect(result.current.value).toBe(true);
    });

    test.each([
        false,
        true,
    ])('unset %s', (initialExpanded) => {
        const { result } = renderHook(() => useExpandToggle({ initialExpanded }));
        act(() => { result.current.unset(); });

        expect(result.current.action).toBe('');
        expect(result.current.value).toBe(false);
    });

    test.each([
        false,
        true,
    ])('set %s', (initialExpanded) => {
        const { result } = renderHook(() => useExpandToggle({ initialExpanded }));
        act(() => { result.current.set(); });

        expect(result.current.action).toBe('');
        expect(result.current.value).toBe(true);
    });

    test.each([
        false,
        true,
    ])('setWith %s', (initialExpanded) => {
        const { result } = renderHook(() => useExpandToggle({ initialExpanded }));
        act(() => { result.current.setWith('action'); });

        expect(result.current.action).toBe(
            result.current.value
                ? 'action'
                : '',
        );
        expect(result.current.value).toBe(true);
    });

});
