import {
    formatDatetime,
    formatMoney,
} from '@billogram/format';

import money from '@billogram/money';

import type {
    FoundationTableRowSearchFieldValue,
} from '../../types';

import highlight from './highlight';


test('highlight', () => {
    const value = 'cupcake ipsum dolor sit amet';
    const matchingTerms = ['ipsum', 'su', 'o', 'ke', 'ca'];

    const result = highlight(value, matchingTerms, 'default', (token: string) => {
        return `_${token}_`;
    });

    expect(result).toEqual(['cup', '_cake_', ' ', '_ipsum_', ' d', '_o_', 'l', '_o_', 'r sit amet']);
});

test('highlight date', () => {
    const timestamp = +new Date(2000, 0, 1);

    const value = timestamp;
    const matchingTerms = [value.toString()];

    const result = highlight(value, matchingTerms, 'date', (token: string) => {
        return `_${token}_`;
    });

    expect(result).toEqual([`_${formatDatetime(timestamp)}_`]);
});

test('highlight money', () => {
    const value = money.create(42, 'SEK');
    const matchingTerms = ['42'];

    const result = highlight(value, matchingTerms, 'money', (token: string) => {
        return `_${token}_`;
    });

    expect(result).toEqual([`_${formatMoney(money.create(42))}_`, '\u00A0SEK']);
});

test('highlight custom format', () => {
    function format(value: FoundationTableRowSearchFieldValue): string {
        if (typeof value === 'string') {
            return `${value.substring(0, 3)} ${value.substring(3, 5)}`;
        }

        return '';
    }

    const value = '12345';
    const matchingTerms = ['12345'];

    const result = highlight(value, matchingTerms, format, (token: string) => {
        return `_${token}_`;
    });

    expect(result).toEqual(['_123 45_']);
});
