import money from '@billogram/money';

import createMatchesValue from './createMatchesValue';



describe('match default', () => {
    test('should match equal value and term', () => {
        const matchesValue = createMatchesValue('billo', 'default');
        expect(matchesValue('billo')).toBe(true);
    });

    test('should not match non-equal value and term', () => {
        const matchesValue = createMatchesValue('billo', 'default');
        expect(matchesValue('gram')).toBe(false);
    });
});

describe('match date', () => {
    test('should match equal value and term', () => {
        const timestamp = +new Date(2000, 0, 1);

        const value = timestamp;
        const term = timestamp.toString();

        const matchesValue = createMatchesValue(value, 'date');
        expect(matchesValue(term)).toBe(true);
    });

    test('should not match non-equal value and term', () => {
        const value = +new Date(2000, 0, 1);
        const term = (+new Date(2000, 1, 1)).toString();

        const matchesValue = createMatchesValue(value, 'date');
        expect(matchesValue(term)).toBe(false);
    });
});

describe('match money', () => {
    test('should match equal value and term', () => {
        const value = money.create(42);
        const term = '42';

        const matchesValue = createMatchesValue(value, 'money');
        expect(matchesValue(term)).toBe(true);
    });

    test('should not match non-equal value and term', () => {
        const value = money.create(42);
        const term = '41';

        const matchesValue = createMatchesValue(value, 'money');
        expect(matchesValue(term)).toBe(false);
    });

    test('should not match if amount is null', () => {
        const value = money.create(null);
        const term = '41';

        const matchesValue = createMatchesValue(value, 'money');
        expect(matchesValue(term)).toBe(false);
    });
});
